<?xml version="1.0" encoding="UTF-8"?>



    
    <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns="http://www.imsglobal.org/xsd/imscp_v1p1"
        xmlns:imscp="http://www.imsglobal.org/xsd/imscp_v1p1"
        xmlns:imsmd="http://www.imsglobal.org/xsd/imsmd_v1p2"
        xmlns:lom="http://ocw.mit.edu/xmlns/LOM"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
        xmlns:eduCommons="http://cosl.usu.edu/xsd/eduCommonsv1.1"
        xmlns:cwsp="http://www.dspace.org/xmlns/cwspace_imscp"
        xmlns:adlcp="http://www.adlnet.org/xsd/adlcp_rootv1p2"
        xmlns:ocw="http://ocw.mit.edu/xmlns/ocw_imscp"
        version="1.0">   
    
    
    
    <xsl:output method="xml" indent="yes" />
        
    <xsl:template match="/">
        <manifest xsi:schemaLocation="http://www.imsglobal.org/xsd/imscp_v1p1 imscp_v1p2.xsd http://www.imsglobal.org/xsd/imsmd_v1p2 imsmd_v1p2p4.xsd http://cosl.usu.edu/xsd/eduCommonsv1.1 eduCommonsv1.1.xsd">
            <xsl:attribute name="identifier">
                <xsl:value-of select="imscp:manifest/@identifier"/>
            </xsl:attribute>
            <xsl:apply-templates/>
        </manifest>        
    
    
    </xsl:template>
    
        
        
        
        
    <xsl:template match="imscp:manifest/imscp:metadata">
        <metadata>
            <schema>IMS Content</schema>
            <schemaversion>1.2</schemaversion>
            <imsmd:lom>
                <xsl:apply-templates select="lom:general"/>
                <xsl:apply-templates select="lom:lifecycle"/>
            </imsmd:lom>
        </metadata>
    </xsl:template>
    
    <xsl:template match="lom:general">
        <imsmd:general>
            <imsmd:identifier>
                <xsl:value-of select="lom:identifier/lom:entry"/>
            </imsmd:identifier>
            <imsmd:title>
                <imsmd:langstring xml:lang="en">
                    <xsl:value-of select="lom:title/lom:string"/>
                </imsmd:langstring>
            </imsmd:title>
        </imsmd:general>
    </xsl:template>
    
    <xsl:template match="lom:lifecycle">
        <imsmd:lifecycle>
            <xsl:apply-templates select="lom:contribute"/>
        </imsmd:lifecycle>
    </xsl:template>
    
    <xsl:template match="lom:title">
        <imsmd:title>
            <xsl:apply-templates/>
        </imsmd:title>
    </xsl:template>
    
    <xsl:template match="lom:identifier">
        <imsmd:identifier>
            <xsl:value-of select="lom:entry"/>
        </imsmd:identifier>
    </xsl:template>
    
    <xsl:template match="lom:contribute">
        <imsmd:contribute>
            <imsmd:role>
                <imsmd:source>
                    <imsmd:langstring xml:lang="x-none">
                        LOMv1.0
                    </imsmd:langstring>
                </imsmd:source>
                <imsmd:value>
                    <imsmd:langstring xml:lang="x-none">
                        author                        
                    </imsmd:langstring>
                </imsmd:value>
            </imsmd:role>
            <imsmd:centity>
                <imsmd:vcard><xsl:text>BEGIN:VCARD
</xsl:text>
<xsl:text>FN:</xsl:text><xsl:value-of select="lom:entity"/>       
<xsl:text>
</xsl:text><xsl:text>END:VCARD</xsl:text>
                </imsmd:vcard>
            </imsmd:centity>
            <imsmd:date>
                <imsmd:datetime>
                    <xsl:value-of select="lom:date/lom:dateTime"/>
                </imsmd:datetime>
            </imsmd:date>
        </imsmd:contribute>
    </xsl:template>
    
    <xsl:template match="imscp:manifest/imscp:organizations">
        <organizations>
             <xsl:attribute name="default">     
                 <xsl:value-of select = "concat('ORG',@default)" />
             </xsl:attribute>
            <xsl:apply-templates/>
        </organizations>
    </xsl:template>
    
    <xsl:template match="imscp:organization">
        <organization>
            <xsl:attribute name="identifier">
                <xsl:value-of select = "concat('ORG',@identifier    )" />
            </xsl:attribute>
            <xsl:apply-templates/>
        </organization>
    </xsl:template>
    
    <xsl:template match="imscp:title">
        <title><xsl:value-of select="."/></title>
    </xsl:template>
    
    <xsl:template match="imscp:item">
        <item>
            <xsl:attribute name="identifier">
                <xsl:value-of select = "concat('ITM',generate-id())" />
           </xsl:attribute>
            <xsl:attribute name="identifierref">
                <xsl:value-of select = "@identifierref" />
            </xsl:attribute>
            <xsl:choose>
                <xsl:when test="@ocw:sectionTemplateType">
                    <xsl:attribute name="isvisible">
                        <xsl:text>true</xsl:text>
                    </xsl:attribute>
                </xsl:when>
            </xsl:choose>
            <xsl:apply-templates/>
        </item>
    </xsl:template>
    
    <xsl:template match="imscp:resources">
        <resources><xsl:apply-templates/></resources>
    </xsl:template>
    
    <xsl:template match="imscp:resources">
        <resources>
            <xsl:apply-templates select="imscp:resource"/>
        </resources>
    </xsl:template>
        
        
    <xsl:template match="imscp:resource">
        <xsl:variable name="identifier" select="@identifier"/>
        <xsl:variable name="title" select="/imscp:manifest/imscp:organizations//imscp:item[@identifierref=$identifier]/imscp:title"/>
        <xsl:variable name="home" select="/imscp:manifest/imscp:organizations//imscp:item[@identifierref=$identifier]/@ocw:sectionTemplateType"/>
        <xsl:variable name="restype" select="@type"/>
        <xsl:variable name="reshref" select="@href"/>

        <xsl:for-each select="imscp:file">
              <resource>                        
                  <xsl:choose>
                      <xsl:when test="@href=$reshref">
                          <xsl:attribute name="identifier">
                              <xsl:value-of select="$identifier"/>
                          </xsl:attribute>
                          <xsl:attribute name="type">
                              <xsl:value-of select="$restype"/>
                          </xsl:attribute>
                          <xsl:attribute name="href">
                              <xsl:value-of select="@href"/>
                          </xsl:attribute>
                      </xsl:when>
                      <xsl:otherwise>
                          <xsl:attribute name="identifier">
                              <xsl:value-of select="concat('RES', generate-id())"/>
                          </xsl:attribute>
                          <xsl:attribute name="type">
                              <xsl:text>unknown</xsl:text>
                          </xsl:attribute>
                      </xsl:otherwise>
                  </xsl:choose>
                  <xsl:choose>
                      <xsl:when test="@href=$reshref">
                          <metadata>
                              <imsmd:lom>
                                  <imsmd:general>
                                      <imsmd:title>
                                          <xsl:choose>                                        
                                              <xsl:when test="$title != ''">
                                                  <imsmd:langstring xml:lang="en">
                                                      <xsl:value-of select="$title"/>
                                                  </imsmd:langstring>
                                              </xsl:when>
                                              <xsl:otherwise>
                                                  <imsmd:langstring xml:lang="en">
                                                      <xsl:text>Title</xsl:text>
                                                  </imsmd:langstring>                                                  
                                              </xsl:otherwise>
                                          </xsl:choose>    
                                      </imsmd:title>
                                  </imsmd:general>
                              </imsmd:lom>
                              <xsl:choose>
                                  <xsl:when test="$home='CourseHomePage'">
                                      <eduCommons:eduCommons>
                                          <eduCommons:objectType>Course</eduCommons:objectType>
                                          <eduCommons:license category="Site Default"/>
                                          <eduCommons:clearedCopyright>false</eduCommons:clearedCopyright>
                                      </eduCommons:eduCommons>
                                  </xsl:when>
                              </xsl:choose>
                          </metadata>
                      </xsl:when>
                      <xsl:otherwise>
                          <metadata>
                             <imsmd:lom>
                                 <imsmd:general>
                                     <imsmd:title>
                                         <imsmd:langstring xml:lang="en">
                                             <xsl:text>Title</xsl:text>
                                         </imsmd:langstring>
                                     </imsmd:title>
                                 </imsmd:general>
                             </imsmd:lom>
                          </metadata>
                      </xsl:otherwise>
                  </xsl:choose>
                      
                  <file>
                      <xsl:attribute name="href">
                          <xsl:variable name="base_dir" select="//@xml:base" />
                          <xsl:value-of select="concat($base_dir,@href) " />
                      </xsl:attribute>
                  </file>
                  
                  </resource>
            </xsl:for-each>
    </xsl:template>
    
    <xsl:template match="adlcp:location">
    </xsl:template>
    
</xsl:stylesheet>
